package dataiostream;

import java.util.Scanner;
import java.util.InputMismatchException;
import java.io.IOException;
import java.io.FileOutputStream;
import java.io.DataOutputStream;
import java.io.FileInputStream;
import java.io.DataInputStream;
import java.io.EOFException;

/**
 * Writes and reads student name, grade and credits data to and from
 * binary DataOutputStream and DataInputStream files.
 *
 * @author Carl B. Struck
 * @version  Copyright 2013 (c) SCCC West
 */
public class DataIOStream
{
    private static final Scanner READER = new Scanner(System.in);
	
    /**
     * Driver method for DataOutputStream and DataInputStream demo.
     *
     * @param args the String[] array command line parameter
     */
    public static void main(String[] args)
    {
        try
        {
            output();
            input();
        }
        
        catch (EOFException ex)
        {
            System.out.println("End of file reached");
        }
        
        catch (IOException ex)
        {
            System.out.println("File operation error");
        }

        catch (InputMismatchException ex)
        {
            System.out.println("Non-numeric or non-integer input");
        }

        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }

    /**
     * Writes output student name, grade and credits data to a binary
     * DataOutputStream file.
     *
     * @throws IOException for any file operation failure related to the 'temp.data' file
     * @throws InputMismatchException if user enters non-integer input for 'credits'
     */
    public static void output() throws IOException
    {
        DataOutputStream output = new DataOutputStream( new FileOutputStream("App_Data/temp.data") );

        System.out.print("Enter student first name==> ");
        String firstName = READER.next();

        while ( ! firstName.equalsIgnoreCase("0") )
        {
            System.out.print("Enter student last name==> ");
            String lastName = READER.next();

            System.out.print("Enter student grade==> ");
            String grade = READER.next();

            System.out.print("Enter number of credits==> ");
            int credits = READER.nextInt();

            output.writeUTF(firstName);
            output.writeUTF(lastName);
            output.writeUTF(grade);
            output.writeInt(credits);

            System.out.print("Enter student first name==> ");
            firstName = READER.next();
        }

        output.close();
    }

    /**
     * Reads input student name, grade and credits data from a binary
     * DataInputStream file and writes them to the terminal window.
     *
     * @throws IOException for any file operation related to the 'temp.data' file
     * @throws EOFException for an attempt to read past the end of the 'temp.data' file
     */
    public static void input() throws IOException
    {
        DataInputStream input = new DataInputStream( new FileInputStream("App_Data/temp.data") );

        while (true)
        {
            System.out.println(input.readUTF() + " " + input.readUTF()
                    + "\t" + input.readUTF() + "\t" + input.readInt());
        }
    }
}
