package randomiowithstrings;

import java.util.Scanner;
import java.io.RandomAccessFile;
import java.io.IOException;
import java.util.InputMismatchException;

/**
 * Writes to and reads from a RandomAccessFile with fixed-length String and int
 * variables.
 *
 * @author Carl B. Struck
 * @version Copyright 2005 (c) SCCC West
 */
public class RandomIOWithStrings
{
    private static final Scanner READER = new Scanner(System.in);

    /**
     * Main menu program to input and output RandomAccessFile records.
     *
     * @param args the String[] array command line arguments
     */
    public static void main(String[] args)
    {
        try
        {
            int choice;

            do
            {
                System.out.print("Which operation: input (1); or output (2) ==> ");
                choice = READER.nextInt();

                if (choice == 1)
                {
                    input();
                }
                else if (choice == 2)
                {
                    output();
                }

            } while (choice == 1 || choice == 2);
        }

        catch (IOException ex)
        {
            System.out.println(ex);
        }

        catch (InputMismatchException ex)
        {
            System.out.println(ex);
        }

        catch (Exception ex)
        {
            System.out.println(ex);
        }
    }

    /**
     * Writes student name, grade and credits data to a RandomAccessFile with
     * fixed-length String and int variables.
     *
     * @throws IOException for any invalid file operation
     * @throws InputMismatchException if input for 'credits' is not an integer
     */
    public static void output() throws IOException
    {
        RandomAccessFile studentFile = new RandomAccessFile("App_Data/studentFile.data", "rw");

        System.out.print("Enter student first name (or '0' to exit) ==> ");
        String firstName = READER.next();

        while (! firstName.equals("0") )
        {
            System.out.print("Enter student last name==> ");
            String lastName = READER.next();

            System.out.print("Enter student grade==> ");
            String grade = READER.next();

            System.out.print("Enter number of credits==> ");
            int credits = READER.nextInt();

            studentFile.seek(studentFile.length());

            FixedLengthStringIO.writeFixedLengthString(firstName, 15, studentFile);
            FixedLengthStringIO.writeFixedLengthString(lastName, 15, studentFile);
            FixedLengthStringIO.writeFixedLengthString(grade, 2, studentFile);
            studentFile.writeInt(credits);

            System.out.print("Enter student first name==> ");
            firstName = READER.next();
        }

        studentFile.close();
    }

    /**
     * Reads student name, grade and credits data from a RandomAccessFile with
     * fixed-length String and int variables, and prints the data to the
     * terminal window.
     *
     * @throws IOException for any invalid file operation
     * @throws InputMismatchException if 'student ID' is not entered as an integer
     */
    public static void input() throws IOException
    {

        RandomAccessFile studentFile = new RandomAccessFile("App_Data/studentFile.data", "r");

        System.out.print("Enter student ID (1-" + (studentFile.length() / 68) + ")==> ");
        long studentID = READER.nextLong();

        while (studentID >= 1 && studentID <= (studentFile.length() / 68))
        {
            studentFile.seek(68 * (studentID - 1));

            String firstName = FixedLengthStringIO.readFixedLengthString(15, studentFile);
            String lastName = FixedLengthStringIO.readFixedLengthString(15, studentFile);
            String grade = FixedLengthStringIO.readFixedLengthString(2, studentFile);
            int credits = studentFile.readInt();

            System.out.println("Student name: " + firstName.trim() + " " + lastName
                + "\nGrade: " + grade
                + "\nCredits: " + credits + "\n");

            System.out.print("Enter student ID (1-" + (studentFile.length() / 68) + ")==> ");
            studentID = READER.nextLong();
        }

        studentFile.close();
    }
}
